<?php

/** mlbl_inventions */

declare(strict_types=1);

use Fisharebest\Localization\Translation;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleCustomInterface;
use Fisharebest\Webtrees\Module\ModuleCustomTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsTrait;
use Fisharebest\Webtrees\Module\ModuleHistoricEventsInterface;
use Illuminate\Support\Collection;

/** Class mlbl_genealogie */
return new class extends AbstractModule implements ModuleCustomInterface, ModuleHistoricEventsInterface
{
	use ModuleCustomTrait;
	use ModuleHistoricEventsTrait;

	public function title(): string
	{return 'MaLiBeLe Inventions';}

	public function description(): string
	{return "Quelques inventions qui ont un impact plutôt important.";}

	public function customModuleAuthorName(): string 
	{return 'Roland Bouat';}

	/** Date = version au format AAAA-MM-JJ de préférence */
	public function customModuleVersion(): string 
	{return '2023-09-08';} 

	/** URL du fichier texte contenant la référence de la dernière version */
	public function customModuleLatestVersionUrl(): string
	{return 'https://dekri.net/webtrees_histoire-derniere_version.txt';} 

	/** URL de l'éventuelle page d'aide et/ou de présentation */
	public function customModuleSupportUrl(): string 
	{return 'https://dekri.net/spip.php?article61';}


	/**
	 * Ce module doit-il être activé lors de sa première installation ?
	 * @return bool => false (conseillé) ou true
	 */
	public function isEnabledByDefault(): bool
	{return false;}

	/**
	 * Tous les événements fournis par ce module.
	 * @return Collection<int,string>
	 */
	public function historicEventsAll(): Collection
	{
	switch (I18N::languageTag()) {
		/** Langues utilisées */
		case 'fr':
        case 'fr-CA':
		return new Collection([
		/*# généalogie */
"1 EVEN La conserve alimentaire par Nicolas Appert (appertisation)\n2 TYPE inventions\n2 DATE 1795\n2 NOTE Alimentation\n3 CONT voir [Conserve](https://fr.wikipedia.org/wiki/Conserve)",
"1 EVEN Le congélateur par Jacob Perkin.\n2 TYPE inventions\n2 DATE 1834\n2 NOTE Alimentation\n3 CONT voir [Congélateur](https://fr.wikipedia.org/wiki/Congélateur)",
"1 EVEN Le réfrigérateur par James Harrison.\n2 TYPE inventions\n2 DATE 1851\n2 NOTE Alimentation\n3 CONT voir [Réfrigérateur](https://fr.wikipedia.org/wiki/Réfrigérateur)",
"1 EVEN La pasteurisation\n2 TYPE inventions\n2 DATE 1865\n2 NOTE Alimentation : Pasteur dépose un brevet pour un procédé de conservation du vin par chauffage (aussi appliqué à la bière).\n3 CONT voir [Pasteurisation](https://fr.wikipedia.org/wiki/Pasteurisation)",
"1 EVEN La catapulte par Denys l’Ancien à Syracuse\n2 TYPE inventions\n2 DATE -400\n2 NOTE Armements : En réalité, il aurait plutôt recruté les inventeurs de la catapulte.\n3 CONT voir [Catapulte](https://fr.wikipedia.org/wiki/Catapulte)",
"1 EVEN Le canon\n2 TYPE inventions\n2 DATE 1260\n2 NOTE Armements : Invention par le moine Berthold Scharz mais très contestée. Il aurait plutôt introduit la poudre noire en Occident vers 1313.\n3 CONT voir [Canon_(artillerie)](https://fr.wikipedia.org/wiki/Canon_(artillerie))",
"1 EVEN La poudre noire\n2 TYPE inventions\n2 DATE 1318\n2 NOTE Armements : Berthold Scharz introduit la poudre noire en Occident mais peut-être est-ce Roger Bacon vers 1290\n3 CONT voir [Berthold_Schwarz](https://fr.wikipedia.org/wiki/Berthold_Schwarz)",
"1 EVEN La dynamite par Alfred Bernhard Nobel.\n2 TYPE inventions\n2 DATE 1866\n2 NOTE Armements\n3 CONT voir [Dynamite](https://fr.wikipedia.org/wiki/Dynamite)",
"1 EVEN La bombe atomique par l’équipe de Julius Robert Oppenheimer\n2 TYPE inventions\n2 DATE 1945\n2 NOTE Armements\n3 CONT voir [Bombe_A](https://fr.wikipedia.org/wiki/Bombe_A)",
"1 EVEN Le cadran solaire par les égyptiens ou les mésopotamiens.\n2 TYPE inventions\n2 DATE -1500\n2 NOTE Astronomie\n3 CONT voir [Cadran_solaire](https://fr.wikipedia.org/wiki/Cadran_solaire)",
"1 EVEN L’holomètre par Abel Foulon pour mesurer la hauteur d’un point au dessus de l’horizon.\n2 TYPE inventions\n2 DATE 1550\n2 NOTE Astronomie : Ce fut le premier privilège d'invention (brevet) connu en France (1551)\n3 CONT voir [Holomètre_(Abel_Foullon)](https://fr.wikipedia.org/wiki/Holomètre_(Abel_Foullon))",
"1 EVEN Le théodolite par Leonard Digges.\n2 TYPE inventions\n2 DATE 1571\n2 NOTE Astronomie\n3 CONT voir [Théodolite](https://fr.wikipedia.org/wiki/Théodolite)",
"1 EVEN Le télescope\n2 TYPE inventions\n2 DATE 1608\n2 NOTE Astronomie : En Hollande, les États Généraux de 1608 reçoivent successivement la demande de brevet de Hans Lippershey le 2 octobre puis quelques semaines après celle de Jacob Metius\n3 CONT voir [Télescope](https://fr.wikipedia.org/wiki/Télescope)",
"1 EVEN La lunette d’approche\n2 TYPE inventions\n2 DATE ABT 1550\n2 NOTE Astronomie : peut-être était-ce l’ancêtre du télescope…\n3 CONT voir [Hans_Lipperhey](https://fr.wikipedia.org/wiki/Hans_Lipperhey)",
"1 EVEN Galilée invente la lunette astronomique\n2 TYPE inventions\n2 DATE 1610\n2 NOTE Astronomie : Galilée met au point sa lunette astronomique.\n3 CONT voir [Lunette_astronomique](https://fr.wikipedia.org/wiki/Lunette_astronomique)",
"1 EVEN L’avion par Clément Agnès Ader.\n2 TYPE inventions\n2 DATE 1890\n2 NOTE Aviation\n3 CONT voir [Avion](https://fr.wikipedia.org/wiki/Avion)",
"1 EVEN L’écriture\n2 TYPE inventions\n2 DATE -4000\n2 NOTE Communication : Les sumériens inventent l’écriture cunéiforme\n3 CONT voir [Écriture](https://fr.wikipedia.org/wiki/Écriture)",
"1 EVEN Première utilisation du chiffre zéro par les babyloniens.\n2 TYPE inventions\n2 DATE -2000\n2 NOTE Communication : Le nombre 0 a été inventé plus tard vers le Vème siècle.\n3 CONT voir [Zéro_(chiffre)](https://fr.wikipedia.org/wiki/Zéro_(chiffre))",
"1 EVEN Invention du papier par Cai Lun\n2 TYPE inventions\n2 DATE 100\n2 NOTE Communication : Il s’agirait plutôt de techniques de fabrication. Attribution donc très controversée \n3 CONT voir [Papier](https://fr.wikipedia.org/wiki/Papier)",
"1 EVEN Première utilisation de caractères mobiles (en terre cuite) dans l’imprimerie par Bi Sheng.\n2 TYPE inventions\n2 DATE 1040\n2 NOTE Communication\n3 CONT voir [Imprimerie](https://fr.wikipedia.org/wiki/Imprimerie)",
"1 EVEN Installation de la première horloge 'à sonner les heures' à Padoue par Giovanni Dondi.\n2 TYPE inventions\n2 DATE 1364\n2 NOTE Communication\n3 CONT voir [Chronologie_de_l'horlogerie](https://fr.wikipedia.org/wiki/Chronologie_de_l'horlogerie)",
"1 EVEN Premier livre réalisé en Europe par imprimerie par Johannes Gutenberg.\n2 TYPE inventions\n2 DATE 1454\n2 NOTE Communication\n3 CONT voir [Imprimerie](https://fr.wikipedia.org/wiki/Imprimerie)",
"1 EVEN Le crayon par Nicolas-Jacques Comté\n2 TYPE inventions\n2 DATE 1795\n2 NOTE Communication\n3 CONT voir [Crayon](https://fr.wikipedia.org/wiki/Crayon)",
"1 EVEN Le télégraphe par Claude Chappe. On dit ou écrit souvent télégraphe Chappe.\n2 TYPE inventions\n2 DATE BEF 1800\n2 NOTE Communication\n3 CONT voir [Télégraphe_Chappe](https://fr.wikipedia.org/wiki/Télégraphe_Chappe)",
"1 EVEN Nicéphore Nièpce fixe des images sur des plaques d’étain (héliographie)\n2 TYPE inventions\n2 DATE 1826\n2 NOTE Communication (Photographie)\n3 CONT voir [Héliographie](https://fr.wikipedia.org/wiki/Héliographie)",
"1 EVEN Écriture Braille\n2 TYPE inventions\n2 DATE 1829\n2 NOTE Communication : Parution du premier ouvrage utilisant le système d’écriture tactile à points saillants inventé par Louis Braille.\n3 CONT voir [Braille](https://fr.wikipedia.org/wiki/Braille)",
"1 EVEN La photographie par Louis Daguerre. En fait il a inventé... le Daguerréotype.\n2 TYPE inventions\n2 DATE 7 JAN 1839\n2 NOTE Communication : invention 'officielle' \n3 CONT voir [Daguerréotype](https://fr.wikipedia.org/wiki/Daguerréotype)",
"1 EVEN Charles Bourseul invente le concept du téléphone\n2 TYPE inventions\n2 DATE 1854\n2 NOTE Communication : l’invention lui est difficilement attribuée : la France le reconnaît en 1889.\n3 CONT voir [Téléphonie](https://fr.wikipedia.org/wiki/Téléphonie)",
"1 EVEN Le téléphone par Alexander Graham Bell.\n2 TYPE inventions\n2 DATE 1876\n2 NOTE Communication\n3 CONT voir [Téléphone](https://fr.wikipedia.org/wiki/Téléphone)",
"1 EVEN Le haut-parleur par Ernst Werner von Siemens.\n2 TYPE inventions\n2 DATE 1877\n2 NOTE Communication\n3 CONT voir [Haut-parleur](https://fr.wikipedia.org/wiki/Haut-parleur)",
"1 EVEN La radio par Gugliemo Marconi\n2 TYPE inventions\n2 DATE 1895\n2 NOTE Communication\n3 CONT voir [Histoire_de_la_radio](https://fr.wikipedia.org/wiki/Histoire_de_la_radio)",
"1 EVEN Le cinéma par Auguste Lumière à Lyon.\n2 TYPE inventions\n2 DATE 1895\n2 NOTE Communication\n3 CONT voir [Cinéma](https://fr.wikipedia.org/wiki/Cinéma)",
"1 EVEN La télévision (noir et blanc) par John Logie Baird.\n2 TYPE inventions\n2 DATE 1923\n2 NOTE Communication\n3 CONT voir [Télévision](https://fr.wikipedia.org/wiki/Télévision)",
"1 EVEN John Logie Baird diffuse la première image télévisée (télévision mécanique).\n2 TYPE inventions\n2 DATE 1926\n2 NOTE Communication\n3 CONT voir [Télévision_mécanique](https://fr.wikipedia.org/wiki/Télévision_mécanique)",
"1 EVEN Le stylo à bille par László Bíró.\n2 TYPE inventions\n2 DATE 1938\n2 NOTE Communication\n3 CONT voir [Stylo_à_bille](https://fr.wikipedia.org/wiki/Stylo_à_bille)",
"1 EVEN La pile électrique par Alessandro Volta.\n2 TYPE inventions\n2 DATE 1800\n2 NOTE Énergie\n3 CONT voir [Pile_électrique](https://fr.wikipedia.org/wiki/Pile_électrique)",
"1 EVEN L’allumette phosphoriques à friction par Charles Sauria\n2 TYPE inventions\n2 DATE 1831\n2 NOTE Énergie\n3 CONT voir [Allumette](https://fr.wikipedia.org/wiki/Allumette)",
"1 EVEN L’ampoule éléctrique par Thomas Alva Edison.\n2 TYPE inventions\n2 DATE 1879\n2 NOTE Énergie\n3 CONT voir [Lampe_électrique](https://fr.wikipedia.org/wiki/Lampe_électrique)",
"1 EVEN Invention de la pascaline, 1ère machine à calculer\n2 TYPE Inventions\n2 DATE 1642\n2 NOTE Informatique : Blaise Pascal crée la 1ère machine à calculer\n3 CONT voir [Pascaline](https://fr.wikipedia.org/wiki/Pascaline)",
"1 EVEN Commercialisation du premier ordinateur de bureau (Olivetti Programma 101)\n2 TYPE inventions\n2 DATE 1965\n2 NOTE Informatique\n3 CONT voir [ordinateur%20de%20bureau](https://www.lorand.org/ordinateur%20de%20bureau)",
"1 EVEN Naissance de la disquette de 8 pouces.\n2 TYPE inventions\n2 DATE 1967\n2 NOTE Informatique : Lancée par IBM dans sa version 8 pouce) pour stocker les microprogrammes des systèmes 370.\n3 CONT voir [Disquette](https://fr.wikipedia.org/wiki/Disquette)",
"1 EVEN Douglas Engelbart dépose le brevet pour ce qui deviendra un outil indispensable à l’utilisation des ordinateurs, la souris !\n2 TYPE inventions\n2 DATE 1969\n2 NOTE Informatique\n3 CONT voir [Souris_(informatique)](https://fr.wikipedia.org/wiki/Souris_(informatique))",
"1 EVEN Invention de la messagerie électronique et envoi du premier courriel sur ARPAnet.\n2 TYPE inventions\n2 DATE OCT 1972\n2 NOTE informatique\n3 CONT voir [ARPANET](https://fr.wikipedia.org/wiki/ARPANET)",
"1 EVEN Langage C par Dennis Ritchie et Ken Thompson et popularisé par  Brian Kernighan.\n2 TYPE inventions\n2 DATE 1972\n2 NOTE Informatique\n3 CONT voir [C_(langage)](https://fr.wikipedia.org/wiki/C_(langage))",
"1 EVEN Première machine appelée micro-ordinateur par François Gernelle, un Micral N.\n2 TYPE inventions\n2 DATE 1973\n2 NOTE informatique\n3 CONT voir [Ordinateur_personnel](https://fr.wikipedia.org/wiki/Ordinateur_personnel)",
"1 EVEN Roland Moreno crée la carte à puces.\n2 TYPE inventions\n2 DATE 1974\n2 NOTE informatique\n3 CONT voir [Carte_à_puce](https://fr.wikipedia.org/wiki/Carte_à_puce)",
"1 EVEN Apparition de l’IBM PC\n2 TYPE inventions\n2 DATE 4 AUG 1981\n2 NOTE Informatique\n3 CONT voir [IBM_PC](https://fr.wikipedia.org/wiki/IBM_PC)",
"1 EVEN Réalisation des premières 'grandes levées de la Loire'.\n2 TYPE inventions\n2 DATE 1250\n2 NOTE Infrastructure\n3 CONT voir [histoire-des-levees-de-la-loire](https://www.cnrseditions.fr/catalogue/histoire/histoire-des-levees-de-la-loire)",
"1 EVEN Le béton armé par le jardinier Joseph Monier.\n2 TYPE inventions\n2 DATE 1867\n2 NOTE Constructions\n3 CONT voir [Béton_armé](https://fr.wikipedia.org/wiki/Béton_armé)",
"1 EVEN Les lunettes par Alessandro Della Spina\n2 TYPE inventions\n2 DATE ABT 1300\n2 NOTE Médecine : Contrairement à l’idée répandue, Ce n’est pas Salvino Degli Armati qui est un personnage imaginaire.\n3 CONT voir [699-invention-des-lunettes-1300.html](https://www.histoire-pour-tous.fr/inventions/699-invention-des-lunettes-1300.html)",
"1 EVEN Premier vaccin contre la variole par Edward Jenner\n2 TYPE inventions\n2 DATE 1786\n2 NOTE  Médecine\n3 CONT voir [Variole](https://fr.wikipedia.org/wiki/Variole)",
"1 EVEN La douche par Francois Merry Delabost.\n2 TYPE inventions\n2 DATE 1872\n2 NOTE Médecine\n3 CONT voir [Douche](https://fr.wikipedia.org/wiki/Douche)",
"1 EVEN Premier vaccin contre la rage par Louis Pasteur sur une idée de Pierre Victor Galtier.\n2 TYPE inventions\n2 DATE 1885\n2 NOTE Médecine\n3 CONT voir [Rage_(maladie)](https://fr.wikipedia.org/wiki/Rage_(maladie))",
"1 EVEN Production d’acide acétylsalicylique pur qui deviendra en 1899 l’aspirine (Bayer).\n2 TYPE inventions\n2 DATE 1897\n2 NOTE Médecine\n3 CONT voir [Acide_acétylsalicylique](https://fr.wikipedia.org/wiki/Acide_acétylsalicylique)",
"1 EVEN Le BCG, vaccin antituberculeux par Albert Calmette et Camille Guérin.\n2 TYPE inventions\n2 DATE 1921\n2 NOTE Médecine\n3 CONT voir [Vaccin_bilié_de_Calmette_et_Guérin](https://fr.wikipedia.org/wiki/Vaccin_bilié_de_Calmette_et_Guérin)",
"1 EVEN Le vaccin contre le tétanos par l’Institut Mérieux.\n2 TYPE inventions\n2 DATE 1922\n2 NOTE Médecine\n3 CONT voir [Tétanos](https://fr.wikipedia.org/wiki/Tétanos)",
"1 EVEN L’imagerie par résonance magnétique par Isidor Isaac Rabi\n2 TYPE inventions\n2 DATE 1938\n2 NOTE Médecine\n3 CONT voir [Résonance_magnétique_nucléaire](https://fr.wikipedia.org/wiki/Résonance_magnétique_nucléaire)",
"1 EVEN Les techniques de séquençage de l’ADN permettent la caractérisation du génome humain.\n2 TYPE inventions\n2 DATE 2003\n2 NOTE Médecine\n3 CONT voir [Génétique_humaine#Séquençage_du_génome_humain](https://fr.wikipedia.org/wiki/Génétique_humaine#Séquençage_du_génome_humain)",
"1 EVEN Première transplantation d’un cœur artificiel autonome de la société Carmat [3] par Alain Carpentier.\n2 TYPE inventions\n2 DATE 2013\n2 NOTE Médecine\n3 CONT voir [Cœur_artificiel](https://fr.wikipedia.org/wiki/Cœur_artificiel)",
"1 EVEN Mise au point des vaccins à ARN messager contre le virus SARS-CoV-2 selon une technique établie  \n2 TYPE inventions\n2 DATE 2020\n2 NOTE Médecine : Selon une technique établie par Katalin Karikó et développée les firmes BioNTech-Pfizer et Moderna.\n3 CONT voir [Vaccin_à_ARN](https://fr.wikipedia.org/wiki/Vaccin_à_ARN)",
"1 EVEN Invention du baromètre à tube de mercure\n2 TYPE Inventions\n2 DATE 1644\n2 NOTE Physique : Evangelista Torricelli met en évidence la pression atmosphérique. En 1648 Blaise Pascal montre que la pression varie avec l’altitude (expérience du Puy-de-Dôme). \n3 CONT voir [Baromètre](https://fr.wikipedia.org/wiki/Baromètre)",
"1 EVEN Principe du moteur à combustion et explosion\n2 TYPE inventions\n2 DATE 1673\n2 NOTE Physique : Christian Huygens et son jeune assistant Denis Papin mettent au point un dispositif constitué d’un cylindre métallique équipé d’un piston\n3 CONT voir [Denis_Papin](https://fr.wikipedia.org/wiki/Denis_Papin)",
"1 EVEN La machine à vapeur par Denis Papin\n2 TYPE inventions\n2 DATE 1679\n2 NOTE Physique : c’est en fait une chaudière équipée d’une soupape avec l’idée du piston qu’il ne parviendra pas à actionner correctement avec son prototype de 1690\n3 CONT voir [Machine_à_vapeur](https://fr.wikipedia.org/wiki/Machine_à_vapeur)",
"1 EVEN Le thermomètre à mercure\n2 TYPE inventions\n2 DATE 1724\n2 NOTE Physique : Daniel Gabriel Fahrenheit invente le thermomètre à mercure.\n3 CONT voir [Thermomètre_à_mercure](https://fr.wikipedia.org/wiki/Thermomètre_à_mercure)",
"1 EVEN Le paratonnerre par Benjamin Franklin\n2 TYPE inventions\n2 DATE 1752\n2 NOTE Physique\n3 CONT voir [Paratonnerre](https://fr.wikipedia.org/wiki/Paratonnerre)",
"1 EVEN La roue\n2 TYPE inventions\n2 DATE -3500\n2 NOTE Transports : On ne sait pas trop où… L’origine sumérienne est très contestée ; peut-être en Mésopotamie ou en Pologne ?\n3 CONT voir [Roue](https://fr.wikipedia.org/wiki/Roue)",
"1 EVEN Le bateau à vapeur par Denis Papin\n2 TYPE inventions\n2 DATE 1707\n2 NOTE Transports\n3 CONT voir [Bateau_à_vapeur](https://fr.wikipedia.org/wiki/Bateau_à_vapeur)",
"1 EVEN Le fardier à vapeur de Joseph Cugnot est le premier véhicule automobile fonctionnel (état de prototype)\n2 TYPE inventions\n2 DATE 1769\n2 NOTE Transports\n3 CONT voir [Nicolas_Joseph_Cugnot](https://fr.wikipedia.org/wiki/Nicolas_Joseph_Cugnot)",
"1 EVEN La montgolfière par Étienne Montgolfier.\n2 TYPE inventions\n2 DATE 1782\n2 NOTE Transports\n3 CONT voir [Montgolfière](https://fr.wikipedia.org/wiki/Montgolfière)",
"1 EVEN Le célérifère (ancêtre du vélo) par le Comte Mede de Sivrac (d’autres disent par Léonard de Vinci).\n2 TYPE inventions\n2 DATE 1790\n2 NOTE Transports : Attention... ! Cest une supercherie du journaliste Louis Baudry de Saunier\n3 CONT voir [Célérifère](https://fr.wikipedia.org/wiki/Célérifère)",
"1 EVEN Première circulation sur des rails d’une locomotive à vapeur\n2 TYPE inventions\n2 DATE 21 FEB 1804\n2 NOTE Transports : Elle a été construite par Richard Trevithick près de Merthyr Tydfil, au pays de Galles\n3 CONT voir [Chemin_de_fer](https://fr.wikipedia.org/wiki/Chemin_de_fer)",
"1 EVEN La draisienne par Karl Drais von Sauebronn\n2 TYPE inventions\n2 DATE 1817\n2 NOTE Transports\n3 CONT voir [Draisienne](https://fr.wikipedia.org/wiki/Draisienne)",
"1 EVEN Première concession d'une ligne de chemin de fer en France\n2 TYPE inventions\n2 DATE 30 JUN 1827\n2 NOTE Transports : Par ordonnance du roi Louis XVIII, c’est celle de la ligne de Saint-Étienne à Andrézieux pour le transport de houille. Elle a été mise en service le 30 juin 1827. C’est donc la première d'Europe continentale.\n3 CONT voir [Histoire_des_chemins_de_fer_franç7ais](https://fr.wikipedia.org/wiki/Histoire_des_chemins_de_fer_franç7ais)",
"1 EVEN Charles Dietz habille les roues d’une bande caoutchouc (ancêtre du pneu)\n2 TYPE inventions\n2 DATE 1830\n2 NOTE Transports\n3 CONT voir [Charles_Dietz](https://fr.wikipedia.org/wiki/Charles_Dietz)",
"1 EVEN Le tramway par John Stephenson à New-York\n2 TYPE inventions\n2 DATE 1832\n2 NOTE Transports\n3 CONT voir [Tramway](https://fr.wikipedia.org/wiki/Tramway)",
"1 EVEN Naissance officielle de l’industrie pétrolière (le pétrole existe depuis l’Antiquité).\n2 TYPE inventions\n2 DATE 1859\n2 NOTE Transports\n3 CONT voir [Histoire_du_pétrole](https://fr.wikipedia.org/wiki/Histoire_du_pétrole)",
"1 EVEN La michaudine (draisienne à pédales)\n2 TYPE inventions\n2 DATE 1861\n2 NOTE Transports : première bicyclette (?) par Pierre Michaux et son fils Ernest.\n3 CONT voir [Michaudine](https://fr.wikipedia.org/wiki/Michaudine)",
"1 EVEN Le pneu (pneumatique) pour les vélos par John Boyd Dunlop.\n2 TYPE inventions\n2 DATE 1889\n2 NOTE Transports\n3 CONT voir [Pneumatique_(véhicule)](https://fr.wikipedia.org/wiki/Pneumatique_(véhicule))",
"1 EVEN L’escalier mécanique par Jesse W. Reno (le premier escalator apparaîtra en 1898 )\n2 TYPE inventions\n2 DATE 1892\n2 NOTE Transports\n3 CONT voir [Escalier_mécanique](https://fr.wikipedia.org/wiki/Escalier_mécanique)",
"1 EVEN La rustine par Louis Rustin.\n2 TYPE inventions\n2 DATE 1922\n2 NOTE Transports\n3 CONT voir [Rustine](https://fr.wikipedia.org/wiki/Rustine)",
"1 EVEN Le mètre ruban par le tailleur Barde.\n2 TYPE inventions\n2 DATE 1814\n2 NOTE D’autres l’attribuent à Alexis Lavigne tailleur pour dames en 1847.\n3 CONT voir [Mètre_ruban](https://fr.wikipedia.org/wiki/Mètre_ruban)",

				]);

			default:
				return new Collection();
		}
	}
};
/** Bonne utilisation */